# -*- coding: utf-8 -*-
'''
Advanced Interface Switcher
2010(c) Kirill Plyashkevich <ru.spirit@gmail.com>
Statusbar item wrapper
'''

import hildon

try:
  from hildondesktop import StatusMenuItem
  from advifswlib.core.maemo5 import *
  hd_plugin_type = get_hd_plugin_type()
except Exception, e:
  print e

# The code below is just for testing purposes.
# It allows to run the widget as a standalone process.
if __name__ == "__main__":
  import sys
  plugin_id = "advanced-interface-switcher.console"
  if len(sys.argv) == 2:
    try:
      plugin_id = "advanced-interface-switcher.desktop-%s" % int(sys.argv[1])
    except:
      print "Plugin id must be integer"
      sys.exit(-1)

    import gobject
    print 'Loading...'
    from hildondesktop import StatusMenuItem
    from advifswlib.core.maemo5 import *
    hd_plugin_type = get_hd_plugin_type()
    print 'Registering type %s...' % (hd_plugin_type)
    gobject.type_register(hd_plugin_type)
    print 'Creating object...'
    obj = gobject.new(hd_plugin_type, plugin_id=plugin_id)
    print 'Showing...'
    obj.show_all()
    print 'Loaded. Starting gtk.main()'
    gtk.main()
